---
icon: "material/head-question"
---

# Semantics

The semantics encoding defines how the satisfaction will be computed, giving semantics to the new grammar.

To write the semantics encoding we provide a set of available encodings that can be imported using `#import "metasp.<file_name>.lp".`.
You can include such encodings to your semantics and write only the semantics relevant to your system.

The available encodings can be found in the [Encodings](../../reference/encodings) section.
